# IronCalc Base

[![Crates.io][crates-badge]][crates-url]
[![MIT licensed][mit-badge]][mit-url]

[crates-badge]: https://img.shields.io/crates/v/ironcalc_base.svg
[crates-url]: https://crates.io/crates/ironcalc_base
[mit-badge]: https://img.shields.io/badge/license-MIT-blue.svg
[mit-url]: https://github.com/ironcalc/ironcalc/blob/master/LICENSE


## About

IronCalc Base is the engine of the IronCalc ecosystem


## Build
To build the library

```bash
$ cargo build --release
```

## Tests

To run the tests:

```bash
$ cargo tests
```






